Defines the public endpoint for the AWS Lake Formation service.
If you’re using the service, you’re probably looking for LakeFormationClient and LakeFormation.
Structs
- Batch
Grant Permissions Request - Batch
Grant Permissions Response - Batch
Permissions Failure Entry A list of failures when performing a batch grant or batch revoke operation.
- Batch
Permissions Request Entry A permission to a resource granted by batch operation to the principal.
- Batch
Revoke Permissions Request - Batch
Revoke Permissions Response - Catalog
Resource A structure for the catalog object.
- Column
Wildcard A wildcard object, consisting of an optional list of excluded column names or indexes.
- Data
Lake Principal The AWS Lake Formation principal. Supported principals are IAM users or IAM roles.
- Data
Lake Settings A structure representing a list of AWS Lake Formation principals designated as data lake administrators and lists of principal permission entries for default create database and default create table permissions.
- Data
Location Resource A structure for a data location object where permissions are granted or revoked.
- Database
Resource A structure for the database object.
- Deregister
Resource Request - Deregister
Resource Response - Describe
Resource Request - Describe
Resource Response - Error
Detail Contains details about an error.
- Filter
Condition This structure describes the filtering of columns in a table based on a filter condition.
- GetData
Lake Settings Request - GetData
Lake Settings Response - GetEffective
Permissions ForPath Request - GetEffective
Permissions ForPath Response - Grant
Permissions Request - Grant
Permissions Response - Lake
Formation Client - A client for the AWS Lake Formation API.
- List
Permissions Request - List
Permissions Response - List
Resources Request - List
Resources Response - Principal
Permissions Permissions granted to a principal.
- Principal
Resource Permissions The permissions granted or revoked on a resource.
- PutData
Lake Settings Request - PutData
Lake Settings Response - Register
Resource Request - Register
Resource Response - Resource
A structure for the resource.
- Resource
Info A structure containing information about an AWS Lake Formation resource.
- Revoke
Permissions Request - Revoke
Permissions Response - Table
Resource A structure for the table object. A table is a metadata definition that represents your data. You can Grant and Revoke table privileges to a principal.
- Table
Wildcard A wildcard object representing every table under a database.
- Table
With Columns Resource A structure for a table with columns object. This object is only used when granting a SELECT permission.
This object must take a value for at least one of
ColumnsNames,ColumnsIndexes, orColumnsWildcard.- Update
Resource Request - Update
Resource Response
Enums
- Batch
Grant Permissions Error - Errors returned by BatchGrantPermissions
- Batch
Revoke Permissions Error - Errors returned by BatchRevokePermissions
- Deregister
Resource Error - Errors returned by DeregisterResource
- Describe
Resource Error - Errors returned by DescribeResource
- GetData
Lake Settings Error - Errors returned by GetDataLakeSettings
- GetEffective
Permissions ForPath Error - Errors returned by GetEffectivePermissionsForPath
- Grant
Permissions Error - Errors returned by GrantPermissions
- List
Permissions Error - Errors returned by ListPermissions
- List
Resources Error - Errors returned by ListResources
- PutData
Lake Settings Error - Errors returned by PutDataLakeSettings
- Register
Resource Error - Errors returned by RegisterResource
- Revoke
Permissions Error - Errors returned by RevokePermissions
- Update
Resource Error - Errors returned by UpdateResource
Traits
- Lake
Formation - Trait representing the capabilities of the AWS Lake Formation API. AWS Lake Formation clients implement this trait.